@@ -1,4 +1,4 @@
-### xtable 1.0-8  (2001/12/15)
+### xtable 1.0-9  (2001/08/21)
 ###
 ### Produce LaTeX and HTML tables from R objects.
 ###
@@ -19,8 +19,7 @@
 ### License along with this program; if not, write to the Free
 ### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 ### MA 02111-1307, USA
-
-print.xtable <- function(x,type="latex",file="",append=FALSE, vsep="", ...) {
+print.xtable <- function(x,type="latex",file="",append=FALSE, ...) {
 
   if (length(type)>1)
     stop("\"type\" must have length 1")
@@ -34,7 +33,11 @@ print.xtable <- function(x,type="latex",file="",append=FALSE, vsep="", ...) {
     ETABLE <- "\\end{center}\n\\end{table}\n"
 #    BTABULAR <- string("\\begin{tabular}{|") + paste(attr(x,"align"),collapse="|") + "|}\n\\hline\n"
 #    See e-mail from "BXC (Bendix Carstensen)" <bxc@novonordisk.com> dated Mon, 27 Aug 2001 10:11:54 +0200
-    BTABULAR <- paste( "\\begin{tabular}{", vsep, paste(attr(x, "align"), collapse = vsep), vsep, "}\n\\hline\n" )
+    BTABULAR <- paste("\\begin{tabular}{", 
+                      paste(attr(x, "vsep"),
+                            c(attr(x, "align"), "}\n\\hline\n"),
+                            sep="", collapse=""),
+                      sep="")
     ETABULAR <- "\\hline\n\\end{tabular}\n"
     BLABEL <- "\\label{"
     ELABEL <- "}\n"
@@ -104,7 +107,7 @@ print.xtable <- function(x,type="latex",file="",append=FALSE, vsep="", ...) {
   result <- string("",file=file,append=append)
   info <- R.Version()
   result <- result + BCOMMENT + type + " table generated in " +
-            info$language + " " + info$major + "." + info$minor + " by xtable 1.0-8 package" + ECOMMENT
+            info$language + " " + info$major + "." + info$minor + " by xtable 1.0-9 package" + ECOMMENT
   result <- result + BCOMMENT + date() + ECOMMENT
   result <- result + BTABLE
   if ((!is.null(attr(x,"caption"))) && (type=="html")) result <- result + BCAPTION + attr(x,"caption") + ECAPTION 
